; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Super Motions |--------------------------------------------------------
[command]
name = "shock"
command =  D,DF,F,z+c
time = 100

[Command]
name = "star"     ;Required (do not remove)
command = D,DF,F,z
time = 100

[Command]
name = "star"     ;Required (do not remove)
command = D,DB,B,z
time = 100

[Command]
name = "r2d2"     ;Required (do not remove)
command = y+z
time = 70

[Command]
name = "ab"     ;Required (do not remove)
command = s
time = 70

[Command]
name = "slide"     ;Required (do not remove)
command = D,DF,F,c
time = 100

[Command]
name = "slide"     ;Required (do not remove)
command = D,DB,B,c
time = 100

[Command]
name = "ship"     ;Required (do not remove)
command = D,DF,F,y+z
time = 100


[Command]
name = "force"     ;Required (do not remove)
command = D,DF,F,a+b
time = 100


[Command]
name = "trickshot"     ;Required (do not remove)
command = D,DF,F,x
time = 70

[Command]
name = "trickshot"     ;Required (do not remove)
command = D,DF,F,y
time = 70


[Command]
name = "sister"     ;Required (do not remove)
command = D,DF,F,a
time = 70

[Command]
name = "sister"     ;Required (do not remove)
command = D,DF,F,b
time = 70



[Command]
name = "switch"     ;Required (do not remove)
command = D,DB,B,x
time = 70

[Command]
name = "switch"     ;Required (do not remove)
command = D,DB,B,y
time = 70



[Command]
name = "han"     ;Required (do not remove)
command = D,DB,B,a
time = 70

[Command]
name = "han"     ;Required (do not remove)
command = D,DB,B,b
time = 70


[Command]
name = "assist"     ;Required (do not remove)
command = ~30$B,F,c
time = 80




;-| Special Motions |------------------------------------------------------

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;===========================================================================
[State -1, AI Activation]
type = varset
triggerall = AILevel > 2
triggerall = (roundstate = 2) && (var(59) = 0)
trigger1 = Random <= ((AILevel-2)*100)
v = 59
value = 1

[State -1, AI Deactivation]
type = varset
triggerall = AIlevel < 7
triggerall = var(59) = 1
trigger1 = Random > ((AILevel-2)*100)
trigger2 = roundstate != 2
v = 59
value = 0
;--|-AI Defense-|-----------------------------------------------------------
[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = (Ctrl) && (p2movetype = A) && (statetype = S)
trigger1 = (p2bodydist X >= 21) && (random <= 799)
value = 130
[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = (Ctrl) && (p2movetype = A) && (statetype = S)
trigger1 = (p2bodydist X >= 2) && (random <= 799)&& (p2statetype=A)
value = 3112

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = (Ctrl) && (p2movetype = A) && (statetype = S)
trigger1 = (p2bodydist X >= 180) && (random <= 799)
value = 711

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = (Ctrl) && (p2movetype = A) && (statetype = S) && (p2statetype = A)
trigger1 = (p2bodydist X >= 31) && (random <= 799)
value = 4201





[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = (Ctrl) && (p2movetype = A) && (statetype = C)
trigger1 = (p2bodydist X >= 50) && (random <= 799)
value = 131

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = (Ctrl) && (p2movetype = A) && (statetype = C)
trigger1 = (p2bodydist X <= 49) && (random <= 799)
value = 420

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = (Ctrl) && (p2movetype = A) && (statetype = A)
trigger1 = (p2bodydist X <= 250) && (random <= 799)
value = 132

;-|-AI Special Attempt-|---------------------------------------------


[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype = S) && (random = [70,100])
trigger1 = (prevstateno != 5120) && (p2statetype != A) && (statetype != A)
value = 899

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype = S) && (random = [70,100])
trigger1 = (prevstateno != 5120) && (p2statetype != A) && (statetype != A)
value = 240

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype = C) && (random = [70,100])
trigger1 = (prevstateno != 5120) && (p2statetype != A)
value = 4200

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype != A) && (random = [170,200])
trigger1 = (prevstateno != 5120) && (p2statetype = A)
value = 4201


[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype != A) && (random = [0,500])
trigger1 = (p2bodydist x <= 119) && (prevstateno != 5120) && (p2movetype = A)
value = 4202


[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype = S) && (random = [0,500])&& (p2statetype = A)
trigger1 = (p2bodydist x >= 40) && (prevstateno != 5120) && (p2movetype = H)
value= 240


[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype = S) && (random = [0,500])
trigger1 = (p2bodydist x <= 99) && (prevstateno != 5120) && (p2movetype != H)
value = 620

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype != A) && (random = [0,500])
trigger1 = (p2bodydist x <= 20) && (prevstateno != 5120) && (p2movetype = H)
value = 451

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype != A) && (random = [0,500])
trigger1 = (p2bodydist x <= 10) && (prevstateno != 5120) && (p2movetype != H)
value = 452

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype != A) && (random = [0,500])
trigger1 = (p2bodydist x <= 28) && (prevstateno != 5120) && (p2movetype != H)
value = 3112

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype != A) && (random = [0,500])
trigger1 = (p2bodydist x <= 52) && (prevstateno != 5120) && (p2movetype != H)
value = 451

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype != A) && (random = [0,500])
trigger1 = (p2bodydist x <= 77) && (prevstateno != 5120) && (p2movetype != H)
value = 230

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = NumHelper(447) =0
triggerall = (Ctrl) && (Statetype = S) && (random = [0,500])
trigger1 = (p2bodydist x <= 60) && (prevstateno != 5120) && (p2movetype != H)
value = 410

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype = S) && (random = [0,500])
trigger1 = (p2bodydist x <= 75) && (prevstateno != 5120) && (p2movetype != H)
trigger1 = stateno > 1200
value = 220

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype = C) && (random = [0,500])
trigger1 = (p2bodydist x <= 110) && (prevstateno != 5120) && (p2movetype != H)
trigger1 = stateno > 1200
value = 2401



[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype != A) && (random = [0,500])
trigger1 = (p2bodydist x >= 70) && (prevstateno != 5120) && (p2movetype != H)
trigger1 = stateno > 1200
value = 2400

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = NumHelper(443) =0
triggerall = (Ctrl) && (Statetype = S) && (random = [0,500])
trigger1 = (p2bodydist x <= 35) && (prevstateno != 5120) && (p2movetype != H)
value = 2402



[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype = A) && (random = [0,500])
trigger1 = (p2bodydist x >= 5) && (prevstateno != 5120) && (p2movetype = H)
trigger1 = stateno > 1200
value = 650

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype = S) && (random = [0,500])
trigger1 = (p2bodydist x <= 90) && (prevstateno != 5120) && (p2movetype != H)
trigger1 = stateno > 1200
value = 711

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (var(59) != 0)
triggerall = stateno < 3000
triggerall = (Ctrl) && (Statetype = A) && (random = [0,500])
trigger1 = (p2bodydist x >= 22) && (prevstateno != 5120) && (p2movetype != H)
trigger1 = stateno > 1200
value = 610

;===========================================================================


[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (anim != [316,319]) && (p2bodydist x <=200)
triggerall = (roundstate = 2) && (var(59) != 0)  && (statetype != A)
triggerall = (Ctrl) && (p2statetype = A)
trigger1 = (power >=1000) && (random = [0,300])
value = 712

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (anim != [316,319]) && (p2bodydist x <= 79)
triggerall = (roundstate = 2) && (var(59) != 0) &&(p2statetype != A)
triggerall = (Ctrl)  && (p2statetype != L)
trigger1 = (power >=1000) && (random = [0,300]) && (statetype != A)
value = 4204

[State -1, Artificial Intelligence]
type = ChangeState
triggerall = (anim != [316,319]) && (p2bodydist x >= 80)
triggerall = (roundstate = 2) && (var(59) != 0)
triggerall = (Ctrl)  && (p2statetype != A)
trigger1 = (power >=1000) && (random = [0,300]) && (statetype != A)
value =4203

;---------------------------------------------------------------------------
; Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------


;===========================================================================


;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 4205
triggerall = command = "s"
trigger1 = statetype != A
trigger1 = ctrl
;-------------------------------------------
[State -1, shock]
type = ChangeState
value = 712
triggerall = command = "shock"
triggerall = power >=1000
triggerall = statetype= S
trigger1 = ctrl
;-----------------------------------------
[State -1, trickshot]
type = ChangeState
value = 452
triggerall = command = "switch"
triggerall = statetype= S
trigger1 = ctrl
;-----------------------------------------
[State -1, ship]
type = ChangeState
value = 4203
triggerall = command = "ship"
triggerall = power >=1000
triggerall = statetype= S
trigger1 = ctrl
;---------------------
[State -1, r2d2]
type = ChangeState
value = 899
triggerall = command = "r2d2"
triggerall = statetype= C
trigger1 = ctrl

;-----------------------------------------
[State -1, force]
type = ChangeState
value = 4204
triggerall = command = "force"
triggerall = power >=1000
triggerall = statetype= S
trigger1 = ctrl
;-----------------------------
[State -1, :)]
type = ChangeState
value = 4202
triggerall = command = "sister"
triggerall = statetype = S
triggerall = NumProjID(1004) = 0
trigger1 = ctrl
;------------------------------------------
[State -1, :)]
type = ChangeState
value = 4205
triggerall = command = "ab"
triggerall = statetype = S
triggerall = NumProjID(33) = 0
trigger1 = ctrl
;-----------------------------
[State -1, :)]
type = ChangeState
value = 4200
triggerall = command = "assist"
triggerall = statetype = S
triggerall = NumProjID(1011) = 0
trigger1 = ctrl
;------------------------------
[State -1, :)]
type = ChangeState
value = 4201
triggerall = command = "han"
triggerall = statetype = S
triggerall = NumProjID(1005) = 0
trigger1 = ctrl
;-------------------------------------------------------
[State -1, star]
type = ChangeState
value = 3112
triggerall = command = "star"
triggerall = statetype != A
trigger1 = ctrl
;---------------------------
[State -1, slide]
type = ChangeState
value = 711
triggerall = command = "slide"
trigger1 = statetype != A
trigger1 = ctrl
;-------------------------------------------------------
[State -1, trickshot]
type = ChangeState
value = 451
triggerall = command = "trickshot"
triggerall = statetype= S
trigger1 = ctrl
;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 220
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 240



;---------------------------------------------------------------------------
; Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 220
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 240


;---------------------------------------------------------------------------
; Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 240

;---------------------------------------------------------------------------
; Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 220
trigger5 = movecontact = 1
trigger5 = stateno = 240


;---------------------------------------------------------------------------
; Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 220

;---------------------------------------------------------------------------
; Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 220
trigger6 = movecontact = 1
trigger6 = stateno = 240


;---------------------


;------------------------------------------------------
; Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 220
trigger6 = movecontact = 1
trigger6 = stateno = 240
trigger7 = movecontact = 1
trigger7 = stateno = 250

;---------------------------------------------------------------------------
; Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 430
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 220
trigger6 = movecontact = 1
trigger6 = stateno = 240
trigger7 = movecontact = 1
trigger7 = stateno = 250

;---------------------------------------------------------------------------
; Crouching Strong Punch
[State -1, Crouching Strong Punch]
type = ChangeState
value = 420
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 410
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
; Crouching Strong Kick
[State -1, Crouching Strong Kick]
type = ChangeState
value = 450
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 200
trigger3 = movecontact = 1
trigger3 = stateno = 210
trigger4 = movecontact = 1
trigger4 = stateno = 230
trigger5 = movecontact = 1
trigger5 = stateno = 220
trigger6 = movecontact = 1
trigger6 = stateno = 240
trigger7 = movecontact = 1
trigger7 = stateno = 250

;---------------------------------------------------------------------------
; Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 650
trigger3 = movecontact = 1
trigger3 = stateno = 610
trigger4 = movecontact = 1
trigger4 = stateno = 630
trigger5 = movecontact = 1
trigger5 = stateno = 620
trigger6 = movecontact = 1
trigger6 = stateno = 640


;---------------------------------------------------------------------------
; Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 650
trigger3 = movecontact = 1
trigger3 = stateno = 600
trigger4 = movecontact = 1
trigger4 = stateno = 630
trigger5 = movecontact = 1
trigger5 = stateno = 620
trigger6 = movecontact = 1
trigger6 = stateno = 640


;---------------------------------------------------------------------------
; Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 620
triggerall = command = "z"
trigger1 = statetype = A
trigger1 = ctrl



;---------------------------------------------------------------------------
; Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 650
trigger3 = movecontact = 1
trigger3 = stateno = 610
trigger4 = movecontact = 1
trigger4 = stateno = 600
trigger5 = movecontact = 1
trigger5 = stateno = 620
trigger6 = movecontact = 1
trigger6 = stateno = 640


;---------------------------------------------------------------------------
; Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = movecontact = 1
trigger2 = stateno = 650
trigger3 = movecontact = 1
trigger3 = stateno = 610
trigger4 = movecontact = 1
trigger4 = stateno = 630
trigger5 = movecontact = 1
trigger5 = stateno = 620
trigger6 = movecontact = 1
trigger6 = stateno = 600


;---------------------------------------------------------------------------
; Jump Strong Kick
[State -1, Jump Strong Kick]
type = ChangeState
value = 650
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl


;---------------------------------------------------------------------------
